@@ -1,7 +1,16 @@
 import asyncio
 
 from deepfos_ipc_protocol.const import MESSAGE_PROTOCOL, HEADER_PROTOCOL, DETAILLIST_PROTOCOL
-from deepfos_ipc_protocol.utils import to_msg_protocol, to_header_protocol, to_detaillist_protocol
+from deepfos_ipc_protocol.utils import (
+    judge_data_format,
+    to_msg_protocol,
+    to_header_protocol,
+    to_detaillist_protocol,
+    logging
+)
+
+
+logger = logging.getLogger(__name__)
 
 
 class ClientProtocol(asyncio.Protocol):
@@ -9,15 +18,14 @@ class ClientProtocol(asyncio.Protocol):
         self.on_con_lost = on_con_lost
 
     def connection_made(self, transport):
-        print("Connection made")
-        # print("Data sent: {!r}".format(self.message))
+        logger.info("Connection made")
 
     def data_received(self, data):
-        print("Data received: {!r}".format(data.decode()))
+        logger.info("Data received: {!r}".format(data.decode()))
 
     def connection_lost(self, exc):
         self.on_con_lost.set_result(True)
-        print("The server closed the connection")
+        logger.info("The server closed the connection")
 
 
 class EchoClientProtocol:
@@ -56,22 +64,5 @@ class EchoClientProtocol:
             transport.close()
 
     def send_msg(self, mtype, message):
+        judge_data_format(mtype, message)
         asyncio.run(self._send_msg(mtype, message))
-
-
-# m = EchoClientProtocol(SOCK_FILE)
-# message = {"task_id": "xxxxadslf"}
-# message2 = {
-#     "key": "key",
-#     "status": "status",
-#     "endTime": "endTime",
-# }
-# message3 = {
-#     "key": "key3",
-#     "status": "status3",
-#     "endTime": "endTime3",
-# }
-# m.send_msg("O", "message")
-# m.send_msg("H", message)
-# m.send_msg("U", message2)
-# m.send_msg("I", [message2, message3])
