@@ -6,9 +6,22 @@ from deepfos_ipc_protocol.const import (
     SUBTASKUPDATE_REVERSE_FIELD_MAP,
     HEADER_META,
     HEADER_FIELD_MAP,
+    MESSAGE_PROTOCOL,
+    HEADER_PROTOCOL,
+    DETAILLIST_PROTOCOL
 )
 
 import sys
+import logging
+
+
+logging.basicConfig(
+    level=logging.INFO,
+    format='[%(asctime)s]: %(filename)s - %(funcName)s - %(message)s',
+    datefmt='%Y-%m-%d %H:%M:%S'
+)
+
+logger = logging.getLogger(__name__)
 
 
 def read_int32(buf):
@@ -25,6 +38,24 @@ def int_to_int16(i: int):
     return i.to_bytes(2, sys.byteorder)
 
 
+def judge_data_format(mtype, data):
+    SUM_PROTOCOL = MESSAGE_PROTOCOL + HEADER_PROTOCOL + DETAILLIST_PROTOCOL
+    if mtype not in SUM_PROTOCOL:
+        logger.error(f"Unknown meta type: {mtype}")
+        raise ValueError(f"Unknown meta type: {mtype}")
+    elif mtype in MESSAGE_PROTOCOL and not isinstance(data, str):
+        logger.error("Message Protocol data must be a string")
+        raise ValueError("Message Protocol data must be a string")
+    elif mtype in HEADER_PROTOCOL and not isinstance(data, dict):
+        logger.error("Header Protocol data must be a dict")
+        raise ValueError("Header Protocol data must be a dict")
+    elif mtype in DETAILLIST_PROTOCOL and not isinstance(data, list):
+        logger.error("DetailList Protocol data must be a list")
+        raise ValueError("DetailList Protocol data must be a list")
+    else:
+        pass
+
+
 def get_filed_map(mtype, reverse: bool) -> Dict[str, str]:
     '''获取字段映射表'''
     if mtype in HEADER_META:
@@ -36,6 +67,7 @@ def get_filed_map(mtype, reverse: bool) -> Dict[str, str]:
             return SUBTASKUPDATE_REVERSE_FIELD_MAP
         return SUBTASKUPDATE_FIELD_MAP
     else:
+        logger.error(f"Unknown meta type: {mtype}")
         raise ValueError("Unknown meta type: {}".format(mtype))
 
 
@@ -61,6 +93,7 @@ def resolve_field_protocol(mtype, num_fields, buf: bytes) -> Dict[str, str]:
     while num_fields and ptr < buf_len:
         key = buf[ptr: ptr + 2]
         if key not in field_map:
+            logger.error(f"Unknown field: {key}")
             raise ValueError(f"Unsupported field: {key}")
         vlen = read_int32(buf[ptr + 2: ptr + 6])
         value = buf[ptr + 6: vlen + ptr + 6]
@@ -69,6 +102,7 @@ def resolve_field_protocol(mtype, num_fields, buf: bytes) -> Dict[str, str]:
         num_fields -= 1
 
     if ptr != buf_len or num_fields != 0:
+        logger.error("Bad message")
         raise ValueError("Bad message")
 
     return result
@@ -149,6 +183,7 @@ def resolve_detaillist_protocol(buf: bytes) -> list:
         while num_fields:
             key = field_buf[ptr: ptr + 2]
             if key not in field_map:
+                logger.error(f"Unknown field: {key}")
                 raise ValueError(f"Unsupported field: {key}")
             vlen = read_int32(field_buf[ptr + 2: ptr + 6])
             value = field_buf[ptr + 6: vlen + ptr + 6]
@@ -159,4 +194,5 @@ def resolve_detaillist_protocol(buf: bytes) -> list:
         yield result
 
         if num_fields != 0:
+            logger.error("Bad message")
             raise ValueError("Bad message")
